"""
    file        ctrccatcher.py
    brief       SpringCore - SpringPark demonstration
    author      Matthieu Barreteau <matthieu.b@springcard.com>
    date        27/01/2021
 
    copyright   Copyright (c) 2021 SPRINGCARD SAS, FRANCE - www.springcard.com
    version     MBA 27/01/2021: initial release, plain connexion

    Purpose:
    On some Windows/Python versions, it could be difficult to interrupt
    the current script. This helpers is used to catch CTRL+C events to force
    the application to exit.
    """
from threading import Thread, Event
from signal import signal, SIGINT
import logging
import time

class CtrlCCatcher(Thread):    

    def __init__(self):
        Thread.__init__(self)        
        self.event = Event()
        self.event.clear()
        signal(SIGINT, self.handler)
    
    def handler(self, signal_received, frame):        
        logging.info( "SIGINT or CTRL-C detected. Exiting gracefully" )
        self.event.set()

    def run(self):
        # do nothing but wait for an interrupt request!
        while not self.event.is_set():
            # no need to eat all cpus
            time.sleep(0.5)

    def wait(self):
        return not self.event.is_set()

    def get_event(self):
        return self.event

    def terminate(self):
        self.event.set()
#eof        